AtRule

Enum AtRule 

pub enum AtRule {
    Media {
        condition: String,
        rules: Vec<RuleSet>,
        span: Range<usize>,
    },
    Import {
        path: String,
        media: Option<String>,
        span: Range<usize>,
    },
    FontFace {
        declarations: Vec<Declaration>,
        span: Range<usize>,
    },
    Keyframes {
        name: String,
        keyframes: Vec<(String, Vec<Declaration>)>,
        span: Range<usize>,
    },
    Other {
        name: String,
        content: String,
        span: Range<usize>,
    },
}
CSS at-rule variant.

Variants



Media

Media query rule (e.g., @media screen and (max-width: 600px)).

Fields

condition: String

The media query condition.

rules: Vec<RuleSet>

The rule sets inside the media query.

span: Range<usize>

The range in the source code where this media rule is defined.



Import

Import rule (e.g., @import "style.css").

Fields

path: String

The import path.

media: Option<String>

Optional media query.

span: Range<usize>

The range in the source code where this import rule is defined.



FontFace

Font face rule (e.g., @font-face).

Fields

declarations: Vec<Declaration>

The font face declarations.

span: Range<usize>

The range in the source code where this font face rule is defined.



Keyframes

Keyframes rule (e.g., @keyframes animation).

Fields

name: String

The animation name.

keyframes: Vec<(String, Vec<Declaration>)>

The keyframe rules.

span: Range<usize>

The range in the source code where this keyframes rule is defined.



Other

Other at-rules.

Fields

name: String

The at-rule name.

content: String

The at-rule content.

span: Range<usize>

The range in the source code where this at-rule is defined.